# pymusicterm

A music player for the terminal written in Python

# Installation

To install `pymusicterm`, it is recommended to use pip:
```
pip install pymusicterm
```

You can install it from source. Clone this repository and use `pip` to install:
```
git clone https://github.com/EGAMAGZ/pymusicterm.git
cd pymusicterm
pip install .
```

If `pymusicterm` is already installed and you would like to update it, use:
```
pip install --upgrade pymusicterm
```

If updating local version, use:
```
cd pymusicterm
git pull
pip install --updgrade .
```

> Note that you may require root acces for installing with `pip` depending on your system's python configuration

<!-- # Demo -->

# Usage
Once `pymusicterm` is intsalled. In a command line client type:
```
pymusicterm
```

In the status bar at the bottom of the window, you will find listed descriptions of how to use the keyboard shortcut to navigate the interface and the menus.

> Windows Terminal is not yet supported
